import classnames from 'classnames';
import { usePagination } from '../Hook/usePagination';

const Pagination = props => {
  const {
    onPageChange,
    totalCount,
    siblingCount = 1,
    currentPage,
    pageSize,
    className
  } = props;

  const paginationRange = usePagination({
    currentPage,
    totalCount,
    siblingCount,
    pageSize,
    className
  });
  if (currentPage === 0 || paginationRange.length < 2) {
    return null;
  }

  const onNext = () => {
    onPageChange(currentPage + 1);
  };

  const onPrevious = () => {
    onPageChange(currentPage - 1);
  };

  let lastPage = paginationRange[paginationRange.length - 1];
  return (
    <nav aria-label="Page navigation example">
    <ul
      className={classnames('pagination', { [className]: className })}
    >
      <li
        className={classnames('page-item', {
          disabled: currentPage === 1
        })}
        
      >
        <a className="page-link" onClick={onPrevious} href="#!">Previous</a>
      </li>
      {paginationRange?.map((pageNumber,key) => {
        if (pageNumber === DOTS) {
          return <li key={key} className="page-item dots">&#8230;</li>;
        }

        return (
          <li key={key}
            className={classnames('page-item', {
                active: pageNumber === currentPage
            })}
           
          >
            <a className="page-link"  onClick={() => onPageChange(pageNumber)} href="#!">{pageNumber}</a>
            
          </li>
        );
      })}
      <li
        className={classnames('page-item', {
          disabled: currentPage === lastPage
        })} 
      >
        <a onClick={onNext} className="page-link" href="#!">Next</a>
      </li>
    </ul>
    </nav>
  );
};

export default Pagination;

